@@ -3,18 +3,18 @@ skip("Expensive manual test")
 test_that("data is cached", {
   path = tempfile()
 
-  oml_data = OMLData$new(9, cache = path)
+  odata = OMLData$new(9, cache = path)
   expect_file_exists(file.path(path, "version.json"))
 
-  expect_list(oml_data$desc)
+  expect_list(odata$desc)
   path_desc = file.path(path, "data_desc", "9.qs")
   expect_file_exists(path_desc)
-  expect_equal(oml_data$desc, qs::qread(path_desc))
+  expect_equal(odata$desc, qs::qread(path_desc))
 
-  expect_data_table(oml_data$data)
+  expect_data_table(odata$data)
   path_data = file.path(path, "data", "9.qs")
   expect_file_exists(path_data)
-  expect_equal(oml_data$data, qs::qread(path_data))
+  expect_equal(odata$data, qs::qread(path_data))
 
   # ensure that cache is not overwritten
   mtime_before = file.mtime(path_data)
@@ -31,9 +31,9 @@ test_that("data is cached", {
   env$versions$data = 9999
 
   # ensure that cache gets invalidated
-  oml_data = OMLData$new(9, cache = path)
+  odata = OMLData$new(9, cache = path)
   expect_false(test_file_exists(path_data))
-  expect_data_table(oml_data$data)
+  expect_data_table(odata$data)
   expect_lt(mtime_before, file.mtime(path_data))
 })
 
